@@ -169,9 +169,10 @@ def build_include_fields_function(
             for field_name in field_names
         ]
     )
+    names_params_str = "" if not names_params else f"{names_params}, "
     s = f"""
-def include_fields(self, {names_params}) -> {node_resolver_name}:
-    fields_to_include: set[str] = set()
+def include_fields(self, {names_params_str}*other_fields: str) -> {node_resolver_name}:
+    fields_to_include: set[str] = set(other_fields)
 {indent_lines(logic_strs)}
     return super().include_fields(*fields_to_include)
     """
